import { ComponentInterface } from '../../../stencil-public-runtime';
import { MediaPlayer } from './MediaPlayer';
export declare const PLAYER_KEY: unique symbol;
export declare const COMPONENT_NAME_KEY: unique symbol;
export declare const REGISTRY_KEY: unique symbol;
export declare const REGISTRATION_KEY: unique symbol;
export declare const REGISTER_COMPONENT_EVENT = "vmComponentRegister";
export declare const DEREGISTER_COMPONENT_EVENT = "vmComponentDeregister";
export declare const COMPONENT_REGISTERED_EVENT = "vmComponentRegistered";
export declare const COMPONENT_DEREGISTERED_EVENT = "vmComponentDeregistered";
export declare type ComponentRegistry = Map<symbol, ComponentRegistrant<HTMLElement>>;
export declare type ComponentRegistrant<T extends HTMLElement = HTMLElement> = T & {
  [COMPONENT_NAME_KEY]: string;
  [PLAYER_KEY]?: HTMLVmPlayerElement;
  [REGISTRY_KEY]?: ComponentRegistry;
  [REGISTRATION_KEY]: symbol;
};
export declare type ComponentRegistrationEvent = CustomEvent<ComponentRegistrant>;
/**
 * Handles registering/deregistering the given `component` in the player registry. All registries
 * are bound per player subtree.
 *
 * @param ref - A Stencil component instance or HTMLElement.
 */
export declare function withComponentRegistry(ref: ComponentInterface | HTMLElement, name?: string): void;
export declare function withComponentRegistrar(player: MediaPlayer): void;
/**
 * Checks whether any component with the given `name` exists in the registry. All registries
 * are bound per player subtree.
 *
 * @param ref - A Stencil component instance or HTMLElement.
 * @param name - The name of the component to search for.
 */
export declare function isComponentRegistered(ref: ComponentInterface | HTMLElement, name: string): boolean;
export declare type ComponentRegistrationChangeCallback<T extends HTMLElement = HTMLElement> = (registrant: ComponentRegistrant<T>[]) => void;
/**
 * Returns the player for the given `ref`. This will only work after the component has been
 * registered, prefer using `findPlayer`.
 *
 * @param ref - A Stencil component instance or HTMLElement.
 */
export declare function getPlayerFromRegistry(ref: unknown): HTMLVmPlayerElement | undefined;
/**
 * Returns a collection of components from the registry for the given `ref`. All registries
 * are bound per player subtree.
 *
 * @param ref - A Stencil component instance or HTMLElement.
 * @param name - The name of the components to search for in the registry.
 */
export declare function getComponentFromRegistry<T extends keyof HTMLElementTagNameMap>(ref: unknown, name: T): ComponentRegistrant<HTMLElementTagNameMap[T]>[];
/**
 * Watches the current registry on the given `ref` for changes. All registries are bound per
 * player subtree.
 *
 * @param ref - A Stencil component instance or HTMLElement.
 * @param name - The name of the component to watch for.
 * @param onChange - A callback that is called when a component is registered/deregistered.
 */
export declare function watchComponentRegistry<T extends keyof HTMLElementTagNameMap>(ref: ComponentInterface | HTMLElement, name: T, onChange?: ComponentRegistrationChangeCallback<HTMLElementTagNameMap[T]>): Promise<() => void>;
