import { EventEmitter } from '../../../stencil-public-runtime';
import { MediaCrossOriginOption, MediaFileProvider, MediaPreloadOption } from '../file/MediaFileProvider';
/**
 * Enables loading, playing and controlling
 * [MPEG DASH](https://en.wikipedia.org/wiki/Dynamic_Adaptive_Streaming_over_HTTP) based media. It
 * uses [`dashjs`](https://github.com/Dash-Industry-Forum/dash.js.md) under the hood.
 *
 * > You don't interact with this component for passing player properties, controlling playback,
 * listening to player events and so on, that is all done through the `vime-player` component.
 */
export declare class Dash implements MediaFileProvider<any> {
  private dash?;
  private dispatch;
  private mediaEl?;
  private videoProvider;
  private textTracksDisposal;
  hasAttached: boolean;
  /**
   * The URL of the `manifest.mpd` file to use.
   */
  src: string;
  onSrcChange(): void;
  /**
   * The NPM package version of the `dashjs` library to download and use.
   */
  version: string;
  /**
   * The URL where the `dashjs` library source can be found. If this property is used, then the
   * `version` property is ignored.
   */
  libSrc?: string;
  /**
   * The `dashjs` configuration.
   */
  config: Record<string, any>;
  /** @internal */
  autoplay: boolean;
  /** @inheritdoc */
  crossOrigin?: MediaCrossOriginOption;
  /** @inheritdoc */
  preload?: MediaPreloadOption;
  /** @inheritdoc */
  poster?: string;
  /** @inheritdoc */
  controlsList?: string;
  /** @inheritdoc */
  autoPiP?: boolean;
  /** @inheritdoc */
  disablePiP?: boolean;
  /** @inheritdoc */
  disableRemotePlayback?: boolean;
  /**
   * The title of the current media.
   */
  mediaTitle?: string;
  /**
   * Are text tracks enabled by default.
   */
  enableTextTracksByDefault: boolean;
  /** @internal */
  shouldRenderNativeTextTracks: boolean;
  onShouldRenderNativeTextTracks(): void;
  /** @internal */
  isTextTrackVisible: boolean;
  /** @internal */
  currentTextTrack: number;
  onTextTrackChange(): void;
  /** @internal */
  vmLoadStart: EventEmitter<void>;
  /**
   * Emitted when an error has occurred.
   */
  vmError: EventEmitter<any>;
  constructor();
  connectedCallback(): void;
  disconnectedCallback(): void;
  private setupDash;
  private destroyDash;
  onMediaElChange(event: CustomEvent<HTMLVideoElement | undefined>): Promise<void>;
  private levelToPlaybackQuality;
  private findLevelIndexFromQuality;
  private dispatchLevels;
  private listenToTextTracksForChanges;
  private getTextTracks;
  private hideCurrentTextTrack;
  private onTextTracksChange;
  /** @internal */
  getAdapter(): Promise<{
    getInternalPlayer: () => Promise<any>;
    canPlay: (type: any) => Promise<boolean>;
    canSetPlaybackQuality: () => Promise<boolean>;
    setPlaybackQuality: (quality: string) => Promise<void>;
    setCurrentTextTrack: (trackId: number) => Promise<void>;
    setTextTrackVisibility: (isVisible: boolean) => Promise<void>;
    play: () => Promise<void | undefined>;
    pause: () => Promise<void | undefined>;
    setCurrentTime: (time: number) => Promise<void>;
    setMuted: (muted: boolean) => Promise<void>;
    setVolume: (volume: number) => Promise<void>;
    canSetPlaybackRate: () => Promise<boolean>;
    setPlaybackRate: (rate: number) => Promise<void>;
    canSetPiP: () => Promise<boolean>;
    enterPiP: () => Promise<any>;
    exitPiP: () => Promise<any>;
    canSetFullscreen: () => Promise<boolean>;
    enterFullscreen: () => Promise<void>;
    exitFullscreen: () => Promise<void>;
  }>;
  render(): any;
}
