import { EventEmitter } from '../../../../stencil-public-runtime';
import { PlayerProps } from '../../../core/player/PlayerProps';
import { KeyboardControl } from './KeyboardControl';
/**
 * A generic player control that is designed to work with both touch and mouse devices. It also
 * seamlessly works with `vime-tooltip`, which can be passed in via the default `slot`.
 *
 * ## Visual
 *
 * <img
 *   src="https://raw.githubusercontent.com/vime-js/vime/master/packages/core/src/components/ui/controls/control/control.png"
 *   alt="Vime control component"
 * />
 *
 * @slot - Used to pass in the content of the control (text/icon/tooltip).
 */
export declare class Control implements KeyboardControl {
  private button;
  private keyboardDisposal;
  host: HTMLVmControlElement;
  describedBy?: string;
  showTapHighlight: boolean;
  /** @inheritdoc */
  keys?: string;
  onKeysChange(): Promise<void>;
  /**
   * The `id` attribute of the control.
   */
  identifier?: string;
  /**
   * Whether the control should be displayed or not.
   */
  hidden: boolean;
  /**
   * The `aria-label` property of the control.
   */
  label: string;
  /**
   * If the control has a popup menu, then this should be the `id` of said menu. Sets the
   * `aria-controls` property.
   */
  menu?: string;
  /**
   * If the control has a popup menu, this indicates whether the menu is open or not. Sets the
   * `aria-expanded` property.
   */
  expanded?: boolean;
  /**
   * If the control is a toggle, this indicated whether the control is in a "pressed" state or not.
   * Sets the `aria-pressed` property.
   */
  pressed?: boolean;
  /** @internal */
  isTouch: PlayerProps['isTouch'];
  /**
   * Emitted when the user is interacting with the control by focusing, touching or hovering on it.
   */
  vmInteractionChange: EventEmitter<boolean>;
  /**
   * Emitted when the control receives focus.
   */
  vmFocus: EventEmitter<void>;
  /**
   * Emitted when the control loses focus.
   */
  vmBlur: EventEmitter<void>;
  constructor();
  connectedCallback(): void;
  componentWillLoad(): void;
  disconnectedCallback(): void;
  /**
   * Focuses the control.
   */
  focusControl(): Promise<void>;
  /**
   * Removes focus from the control.
   */
  blurControl(): Promise<void>;
  private onTouchStart;
  private onTouchEnd;
  private findTooltip;
  private onShowTooltip;
  private onHideTooltip;
  private onFocus;
  private onBlur;
  private onMouseEnter;
  private onMouseLeave;
  render(): any;
}
