import { EventEmitter } from '../../../../stencil-public-runtime';
import { PlayerProps } from '../../../core/player/PlayerProps';
/**
 * A collection of radio buttons describing a set of related options. Only one radio button in a
 * group can be selected at the same time.
 *
 * ## Visual
 *
 * <img
 *   src="https://raw.githubusercontent.com/vime-js/vime/master/packages/core/src/components/ui/settings/menu-radio-group/menu-radio-group.png"
 *   alt="Vime settings menu radio group component"
 * />
 */
export declare class MenuItem {
  private menuItem?;
  host: HTMLVmMenuItemElement;
  showTapHighlight: boolean;
  /**
   * The `id` attribute of the item.
   */
  identifier?: string;
  /**
   * Whether the item is displayed or not.
   */
  hidden: boolean;
  /**
   * The label/title of the item.
   */
  label: string;
  /**
   * If the item has a popup menu, then this should be a reference to it.
   */
  menu?: HTMLVmMenuElement;
  /**
   * If the item has a popup menu, this indicates whether the menu is open or not. Sets the
   * `aria-expanded` property.
   */
  expanded?: boolean;
  /**
   * If this item is to behave as a radio button, then this property determines whether the
   * radio is selected or not. Sets the `aria-checked` property.
   */
  checked?: boolean;
  /**
   * This can provide additional context about some underlying state of the item. For example, if
   * the menu item opens/closes a submenu with options, the hint could be the currently selected
   * option. If `checked` is defined, `hint` is not shown.
   */
  hint?: string;
  /**
   * This can provide additional context about the value of a menu item. For example, if the item
   * is a radio button for a set of video qualities, the badge could describe whether the quality
   * is UHD, HD etc. If `hint` is shown, `badge` is not shown.
   */
  badge?: string;
  /**
   * The name of the checkmark icon to resolve from the icon library.
   */
  checkIcon?: string;
  /**
   * The name of an icon library to use. Defaults to the library defined by the `icons` player
   * property.
   */
  icons?: string;
  /** @internal */
  isTouch: PlayerProps['isTouch'];
  /**
   * Emitted when the item is focused.
   */
  vmFocus: EventEmitter<void>;
  /**
   * Emitted when the item loses focus.
   */
  vmBlur: EventEmitter<void>;
  constructor();
  /**
   * Focuses the menu item.
   */
  focusItem(): Promise<void>;
  /**
   * Removes focus from the menu item.
   */
  blurItem(): Promise<void>;
  /**
   * Returns the height of the menu item.
   */
  getHeight(): Promise<number>;
  private onClick;
  private onFocus;
  private onBlur;
  private onTouchStart;
  private onTouchEnd;
  private onMouseLeave;
  render(): any;
}
