import { EventEmitter } from '../../../../stencil-public-runtime';
/**
 * Menu radio buttons are presented in radio groups (a collection of radio buttons describing a set
 * of related options). Only one radio button in a group can be selected at the same time.
 *
 * ## Visual
 *
 * <img
 *   src="https://raw.githubusercontent.com/vime-js/vime/master/packages/core/src/components/ui/settings/menu-radio/menu-radio.png"
 *   alt="Vime settings menu radio component"
 * />
 */
export declare class MenuRadio {
  /**
   * The title of the radio item displayed to the user.
   */
  label: string;
  /**
   * The value associated with this radio item.
   */
  value: string;
  /**
   * Whether the radio item is selected or not.
   */
  checked: boolean;
  /**
   * This can provide additional context about the value. For example, if the option is for a set of
   * video qualities, the badge could describe whether the quality is UHD, HD etc.
   */
  badge?: string;
  /**
   * The URL to an SVG element or fragment to load.
   */
  checkIcon?: string;
  /**
   * The name of an icon library to use. Defaults to the library defined by the `icons` player
   * property.
   */
  icons?: string;
  /**
   * Emitted when the radio button is selected.
   */
  vmCheck: EventEmitter<void>;
  constructor();
  private onClick;
  render(): any;
}
