import { EventEmitter } from '../../../stencil-public-runtime';
/**
 * A custom styled and ARIA friendly `input[type="range"]` component for inputting numeric values.
 * In addition, there are optimizations made for improved touch support (more information can be
 * found at https://github.com/sampotts/rangetouch).
 */
export declare class Slider {
  host: HTMLVmSliderElement;
  /**
   * A number that specifies the granularity that the value must adhere to.
   */
  step: number;
  /**
   * The lowest value in the range of permitted values.
   */
  min: number;
  /**
   * The greatest permitted value.
   */
  max: number;
  /**
   * The current value.
   */
  value: number;
  /**
   * Human-readable text alternative for the current value. Defaults to `value:max` percentage.
   */
  valueText?: string;
  /**
   * A human-readable label for the purpose of the slider.
   */
  label?: string;
  /**
   * Emitted when the value of the underlying `input` field changes.
   */
  vmValueChange: EventEmitter<number>;
  /**
   * Emitted when the slider receives focus.
   */
  vmFocus: EventEmitter<void>;
  /**
   * Emitted when the slider loses focus.
   */
  vmBlur: EventEmitter<void>;
  constructor();
  private getPercentage;
  private onValueChange;
  private calcTouchedValue;
  /**
   * Basically input[range="type"] on touch devices sucks (particularly iOS), so this helps make it
   * better.
   *
   * @see https://github.com/sampotts/rangetouch
   */
  private onTouch;
  render(): any;
}
